@@ -1,29 +1,19 @@
 use indexmap::indexmap;
-use rocket::response::{Flash, Redirect};
+use rocket::response::Redirect;
 use rocket::serde::{Deserialize, Serialize};
 use std::collections::HashMap;
 
-use printnanny_api_client::models;
 use printnanny_services::config::{ApiConfig, PrintNannyConfig};
 use printnanny_services::printnanny_api::{ApiService, ServiceError};
-use rocket::form::{Context, Contextual, Form, FromForm, ValueField};
+use rocket::form::{Context, Contextual, Form, FromForm};
 use rocket::http::{Cookie, CookieJar};
 use rocket::State;
-use rocket_dyn_templates::tera;
 use rocket_dyn_templates::Template;
 
 use super::error;
 use super::response::{FlashResponse, Response};
 
 pub const COOKIE_CONFIG: &str = "printnanny_config";
-// generic
-#[derive(Debug, Serialize, Deserialize)]
-pub struct DashContext {
-    // api_config: models::PrintNannyApiConfig,
-    user: models::User,
-    device: models::Device,
-    // system_info: models::SystemInfo
-}
 
 #[derive(Debug, FromForm, Serialize, Deserialize)]
 pub struct EmailForm<'v> {
@@ -67,8 +57,6 @@ async fn login_step1_submit<'r>(
     config: &State<PrintNannyConfig>,
 ) -> Result<Response, FlashResponse<Template>> {
     info!("Received auth email form response {:?}", form);
-    let c = config.inner().clone();
-
     match &form.value {
         Some(signup) => {
             let result = handle_step1(signup, config).await?;
@@ -93,9 +81,9 @@ pub async fn handle_device_update(
 ) -> Result<PrintNannyConfig, ServiceError> {
     info!("Sending device info using config {:?}", &config);
     let service = ApiService::new(config)?;
-    let device = service.device_setup().await?;
-    info!("Success! Device info updated: {:?}", device);
-    Ok(service.config)
+    let new_config = service.device_setup().await?;
+    info!("Success! Config updated: {:?}", &new_config);
+    Ok(new_config)
 }
 
 async fn handle_token_validate(
@@ -125,7 +113,7 @@ async fn login_step2_submit<'r>(
     jar: &CookieJar<'_>,
     form: Form<Contextual<'r, TokenForm<'r>>>,
     config: &State<PrintNannyConfig>,
-) -> Result<FlashResponse<Redirect>, FlashResponse<Template>> {
+) -> Result<Response, FlashResponse<Template>> {
     info!("Received auth email form response {:?}", form);
     let c = config.inner().clone();
     match form.value {
@@ -134,10 +122,7 @@ async fn login_step2_submit<'r>(
             let api_config: PrintNannyConfig = handle_token_validate(token, &email, c).await?;
             let cookie_value = serde_json::to_string(&api_config)?;
             jar.add_private(Cookie::new(COOKIE_CONFIG, cookie_value));
-            Ok(FlashResponse::<Redirect>::from(Flash::success(
-                Redirect::to("/login/welcome"),
-                "Verification Success",
-            )))
+            Ok(Response::Redirect(Redirect::to("/")))
         }
         None => {
             info!("form.value is empty");
@@ -154,8 +139,7 @@ async fn login_step3(jar: &CookieJar<'_>) -> Result<Response, FlashResponse<Temp
     match get_api_config {
         Some(cookie) => {
             let config: PrintNannyConfig = serde_json::from_str(cookie.value())?;
-            let context = get_context(config).await?;
-            Ok(Response::Template(Template::render("welcome", context)))
+            Ok(Response::Template(Template::render("welcome", config)))
         }
         None => Ok(Response::Template(Template::render(
             "authemail",
@@ -171,18 +155,6 @@ fn login_step2(email: String) -> Template {
     Template::render("authtoken", context)
 }
 
-pub async fn get_context(config: PrintNannyConfig) -> Result<DashContext, ServiceError> {
-    info!("Sending device info using config {:?}", &config);
-    let service = ApiService::new(config)?;
-    let device = service.device_setup().await?;
-    info!("Success! Device info updated: {:?}", device);
-    let device = service.device_retrieve_hostname().await?;
-    let user = service.auth_user_retreive().await?;
-    let context = DashContext { user, device };
-
-    Ok(context)
-}
-
 #[get("/?<email>")]
 async fn login_step1_email_prepopulated(
     email: &str,
